﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;

namespace WindowsFormsApplication2
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            this.Load += new EventHandler(Form1_Load);
            this.ultraGrid1.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(ultraGrid1_InitializeLayout);
            this.ultraGrid1.BeforePerformAction += new BeforeUltraGridPerformActionEventHandler(ultraGrid1_BeforePerformAction);
        }

        void ultraGrid1_BeforePerformAction(object sender, BeforeUltraGridPerformActionEventArgs e)
        {
            // Check if this is a paste operation
            if (e.UltraGridAction == UltraGridAction.Paste)
            {
                // the string "\r\n" is used between the column name and the values so split the string
                // from the clipboard based on this value
                string[] split = { "\r\n" };
                string[] strings = Clipboard.GetText().Split(split, StringSplitOptions.None);

                // The rows to paste will be the number of strings in the array
                int rowsToPaste = strings.Length;

                // If the array contains an empty string at the end then this will not need a row to be created
                if (strings.Length > 0 && String.IsNullOrEmpty(strings[strings.Length - 1]))
                {                   
                    rowsToPaste--;
                }

                // Determine where the index of the grid where the paste will begin
                // if there is are selected cells use that range and if there aren't any selected cells, use the active row
                int startIndex = 0;
                if (ultraGrid1.Selected.Cells.Count > 0)
                {
                    ultraGrid1.Selected.Cells.Sort();
                    startIndex = ultraGrid1.Selected.Cells[0].Row.Index;
                }
                else
                {
                    startIndex = ultraGrid1.ActiveRow.Index;
                }

                // Calculate the rows needed and then add empty rows to the DataTable the 
                // grid is bound to
                int rowsNeeded = rowsToPaste - (ultraGrid1.Rows.Count - startIndex);
                DataTable data = (DataTable)this.ultraGrid1.DataSource;
                for (int i = 0; i < rowsNeeded; i++)
                {
                    DataRow row = data.NewRow();
                    data.Rows.Add(row);
                }
            }
        }

        void ultraGrid1_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Override.CellClickAction = CellClickAction.CellSelect;
            e.Layout.Override.AllowMultiCellOperations = AllowMultiCellOperation.All;
        }

        void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.DataSource = this.GetEmployees(4);
        }

        // Create sample data
        private DataTable GetEmployees(int count)
        {
            DataTable dtData = new DataTable("SampleData");

            dtData.Columns.Add("A", typeof(string));
            dtData.Columns.Add("B", typeof(string));
            dtData.Columns.Add("C", typeof(string));
            dtData.Columns.Add("D", typeof(string));
            dtData.Columns.Add("E", typeof(string));
            dtData.Columns.Add("F", typeof(string));

            for (int i = 0; i < count; i++)
            {
                dtData.Rows.Add(dtData.NewRow());
            }

            return dtData;
        }
    }
}
